/**
 * libSpiff - XSPF playlist handling library
 *
 * Copyright (C) 2006 Sebastian Pipping
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Sebastian Pipping, webmaster@hartwork.org
 */

#include "Spiff/Spiff.h"
#include <stdio.h>
using namespace Spiff;



class DemoPlaylist : public SpiffCallback {

private:
	void open(XML_Char * type) {
		PORT_PRINTF(_PT("%s (\n"), type);
	}

	void close() {
		PORT_PRINTF(_PT(")\n"));
	}

	void value(XML_Char * value, bool last = false) {
		if (value == NULL) {
			PORT_PRINTF(last ? _PT("  -\n") : _PT("  -,\n"));
		} else {
			PORT_PRINTF(_PT("  %s%s"), value, last ? _PT("\n") : _PT(",\n"));
		}
	}

	void addTrack(SpiffTrack * track) {
		open(_PT("Track"));
		value(track->getCreator());
		value(track->getAlbum());
		value(track->getTrackNum());
		value(track->getTitle());
		value(track->getLocation(), true);
		close();
	}

	void setProperties(SpiffPlaylistProps * props) {
		open(_PT("Props"));
		value(props->getTitle(), true);
		close();
	}

};



int PORT_MAIN() {
	SpiffParser spiffParser(_PT("playlist.xspf"), new DemoPlaylist());
	return 0;
}
